"use strict";
// Copyright IBM Corp. 2019. All Rights Reserved.
// Node module: @loopback/authentication
// This file is licensed under the MIT License.
// License text available at https://opensource.org/licenses/MIT
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
const context_1 = require("@loopback/context");
const core_1 = require("@loopback/core");
const keys_1 = require("../keys");
const types_1 = require("../types");
/**
 * An authentication strategy provider responsible for
 * resolving an authentication strategy by name.
 *
 * It declares an extension point to which all authentication strategy
 * implementations must register themselves as extensions.
 *
 * @example `context.bind('authentication.strategy').toProvider(AuthenticationStrategyProvider)`
 */
let AuthenticationStrategyProvider = class AuthenticationStrategyProvider {
    constructor(authenticationStrategies, metadata) {
        this.authenticationStrategies = authenticationStrategies;
        this.metadata = metadata;
    }
    async value() {
        if (!this.metadata) {
            return undefined;
        }
        const name = this.metadata.strategy;
        const strategy = await this.findAuthenticationStrategy(name);
        if (!strategy) {
            // important to throw a non-protocol-specific error here
            const error = new Error(`The strategy '${name}' is not available.`);
            Object.assign(error, {
                code: types_1.AUTHENTICATION_STRATEGY_NOT_FOUND,
            });
            throw error;
        }
        return strategy;
    }
    async findAuthenticationStrategy(name) {
        const strategies = await this.authenticationStrategies();
        const matchingAuthStrategy = strategies.find(a => a.name === name);
        return matchingAuthStrategy;
    }
};
AuthenticationStrategyProvider = __decorate([
    core_1.extensionPoint(keys_1.AuthenticationBindings.AUTHENTICATION_STRATEGY_EXTENSION_POINT_NAME, { scope: context_1.BindingScope.TRANSIENT }) //this needs to be transient, e.g. for request level context.
    ,
    __param(0, core_1.extensions()),
    __param(1, context_1.inject(keys_1.AuthenticationBindings.METADATA)),
    __metadata("design:paramtypes", [Function, Object])
], AuthenticationStrategyProvider);
exports.AuthenticationStrategyProvider = AuthenticationStrategyProvider;
//# sourceMappingURL=auth-strategy.provider.js.map